@@ -1,7 +1,7 @@
 import click
 
 from dtuhpc.cli.cli_config import CLIConfig
-from dtuhpc.cli.commands import deploy, exec, init, parse, server_command, ssh
+from dtuhpc.cli.commands import deploy, exec, init, server_command, ssh
 from dtuhpc.cli.commands.auth import auth
 
 
@@ -33,7 +33,6 @@ def main():
     cli.add_command(deploy)
     cli.add_command(ssh)
     cli.add_command(auth)
-    cli.add_command(parse)
 
     cli()
 
