@@ -1,8 +1,7 @@
 from .deploy import deploy
 from .exec import exec
 from .init import init
-from .parse import parse
 from .server_command import server_command
 from .ssh import ssh
 
-__all__ = ["deploy", "exec", "init", "ssh", "server_command", "parse"]
+__all__ = ["deploy", "exec", "init", "ssh", "server_command"]
